from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, File, String, Int

Scanwise_V0_1_0 = CommandToolBuilder(tool="scanwise", base_command=["scanwise"], inputs=[ToolInput(tag="in_db_size", input_type=Boolean(optional=True), prefix="-dbsize", doc=InputDocumentation(doc="[number] effective db size for Evalue calculation [300000]")), ToolInput(tag="in_scan_host", input_type=Boolean(optional=True), prefix="-scan_host", doc=InputDocumentation(doc="[localhost] host name for wise server")), ToolInput(tag="in_scan_port", input_type=Boolean(optional=True), prefix="-scan_port", doc=InputDocumentation(doc="[4050]      port for wise server")), ToolInput(tag="in_multiserver", input_type=File(optional=True), prefix="-multiserver", doc=InputDocumentation(doc="Filename for multiple servers, <host> <port> format")), ToolInput(tag="in_seq_db", input_type=Boolean(optional=True), prefix="-seqdb", doc=InputDocumentation(doc="For local cases, sequence database fasta file")), ToolInput(tag="in_seq_dbm_at", input_type=Boolean(optional=True), prefix="-seqdbmat", doc=InputDocumentation(doc="For local cases, comparison matrix to use")), ToolInput(tag="in_hsps_can_impl", input_type=Boolean(optional=True), prefix="-hspscan_impl", doc=InputDocumentation(doc="[vanilla/threaded/twohit] implementation to use if compliled for runtime")), ToolInput(tag="in_hsps_can_max_res", input_type=Boolean(optional=True), prefix="-hspscan_maxres", doc=InputDocumentation(doc="[100] maximum results returned by scan")), ToolInput(tag="in_hsps_can_numb", input_type=Boolean(optional=True), prefix="-hspscan_numb", doc=InputDocumentation(doc="[1000] word count to numb word (for low complexity)")), ToolInput(tag="in_hsps_can_word_depth", input_type=Boolean(optional=True), prefix="-hspscan_worddepth", doc=InputDocumentation(doc="[2] maximum offset from word - [0,1,2]")), ToolInput(tag="in_hsps_can_min_word", input_type=Boolean(optional=True), prefix="-hspscan_minword", doc=InputDocumentation(doc="[14] minimum word score")), ToolInput(tag="in_hsps_can_minh_sp", input_type=Boolean(optional=True), prefix="-hspscan_minhsp", doc=InputDocumentation(doc="[22] minimum hsp score")), ToolInput(tag="in_hsps_can_link_width", input_type=Boolean(optional=True), prefix="-hspscan_link_width", doc=InputDocumentation(doc="[30] max width (gap) of scored HSP chain")), ToolInput(tag="in_hsps_can_link_length", input_type=Boolean(optional=True), prefix="-hspscan_link_length", doc=InputDocumentation(doc="[150] max length of scored HSP chain")), ToolInput(tag="in_hsps_can_verbosity", input_type=Boolean(optional=True), prefix="-hspscan_verbosity", doc=InputDocumentation(doc="[0] verbosity level of server, if server is trace compiled")), ToolInput(tag="in_hsps_can_low_numb", input_type=Boolean(optional=True), prefix="-hspscan_lownumb", doc=InputDocumentation(doc="[0] low complexity numb level, 0 means no special low complexity scores")), ToolInput(tag="in_hsps_can_avg_ext", input_type=Boolean(optional=True), prefix="-hspscan_avgext", doc=InputDocumentation(doc="[-6] average extension minimum in hsp extension")), ToolInput(tag="in_hsp_convert", input_type=Boolean(optional=True), prefix="-hspconvert", doc=InputDocumentation(doc="[ungapped/fulldp/heuristic] Conversion type - heuristic default")), ToolInput(tag="in_hsp_thread", input_type=Boolean(optional=True), prefix="-hspthread", doc=InputDocumentation(doc="multi-thread HSP conversion")), ToolInput(tag="in_hsp_thread_no", input_type=Boolean(optional=True), prefix="-hspthreadno", doc=InputDocumentation(doc="number of HSP threads (4 default)")), ToolInput(tag="in_hsp_two_hit_width", input_type=Boolean(optional=True), prefix="-hsp2hit_width", doc=InputDocumentation(doc="[no] width around each HSP to consider")), ToolInput(tag="in_hsp_two_hit_length", input_type=Boolean(optional=True), prefix="-hsp2hit_length", doc=InputDocumentation(doc="[no] length around each HSP to consider")), ToolInput(tag="in_hsp_two_hit_sub_aln", input_type=Boolean(optional=True), prefix="-hsp2hit_subaln", doc=InputDocumentation(doc="[no] number of HSP subalignments to consider (disabled)")), ToolInput(tag="in_hsp_two_hit_hit_aln", input_type=Boolean(optional=True), prefix="-hsp2hit_hitaln", doc=InputDocumentation(doc="[no] number of hitpairs to assess")), ToolInput(tag="in_hsp_two_hit_best_perc", input_type=Boolean(optional=True), prefix="-hsp2hit_best_perc", doc=InputDocumentation(doc="[10] percentage off best score taken in best-in-search truncation")), ToolInput(tag="in_hit_output", input_type=Boolean(optional=True), prefix="-hitoutput", doc=InputDocumentation(doc="[pseudoblast/xml/tab] pseudoblast by default")), ToolInput(tag="in_hit_help", input_type=Boolean(optional=True), prefix="-hithelp", doc=InputDocumentation(doc="more detailed help on hitlist formats")), ToolInput(tag="in_dy_mem", input_type=Boolean(optional=True), prefix="-dymem", doc=InputDocumentation(doc="memory style [default/linear/explicit]")), ToolInput(tag="in_kbyte", input_type=Boolean(optional=True), prefix="-kbyte", doc=InputDocumentation(doc="memory amount to use [4000]")), ToolInput(tag="in_dy_debug", input_type=Boolean(optional=True), prefix="-dydebug", doc=InputDocumentation(doc="drop into dynamite dp matrix debugger")), ToolInput(tag="in_pal_debug", input_type=Boolean(optional=True), prefix="-paldebug", doc=InputDocumentation(doc="print PackAln after debugger run if used")), ToolInput(tag="in_version", input_type=Boolean(optional=True), prefix="-version", doc=InputDocumentation(doc="show version and compile info")), ToolInput(tag="in_silent", input_type=Boolean(optional=True), prefix="-silent", doc=InputDocumentation(doc="No messages    on stderr")), ToolInput(tag="in_quiet", input_type=Boolean(optional=True), prefix="-quiet", doc=InputDocumentation(doc="No report/info on stderr")), ToolInput(tag="in_error_off_std", input_type=String(optional=True), prefix="-erroroffstd", doc=InputDocumentation(doc="warning messages to stderr")), ToolInput(tag="in_error_log", input_type=Boolean(optional=True), prefix="-errorlog", doc=InputDocumentation(doc="[file] Log warning messages to file")), ToolInput(tag="in_error_style", input_type=Boolean(optional=True), prefix="-errorstyle", doc=InputDocumentation(doc="[server/program] style of error reporting (default program)")), ToolInput(tag="in_seq_load_tile", input_type=Boolean(optional=True), prefix="-seqloadtile", doc=InputDocumentation(doc="tiling skip of load (default 1)")), ToolInput(tag="in_seq_load_report", input_type=Int(optional=True), prefix="-seqloadreport", doc=InputDocumentation(doc="report (using info) at what stagger rating (default none)")), ToolInput(tag="in_seq_load_trunc", input_type=Boolean(optional=True), prefix="-seqloadtrunc", doc=InputDocumentation(doc="<number>  truncate load after this number of sequeneces (useful for debugging)")), ToolInput(tag="in_seq_load_start", input_type=Boolean(optional=True), prefix="-seqloadstart", doc=InputDocumentation(doc="<number>  start position in database for seq load")), ToolInput(tag="in_seq_load_end", input_type=Boolean(optional=True), prefix="-seqloadend", doc=InputDocumentation(doc="<number>  end position in database for seq load")), ToolInput(tag="in_pi_type", input_type=Boolean(optional=True), prefix="-pitype", doc=InputDocumentation(doc="[array/hash/stream/shadow] - default array")), ToolInput(tag="in_pi_way_post", input_type=Boolean(optional=True), prefix="-piwaypost", doc=InputDocumentation(doc="[number]  - waypost for streamed cases, default 3")), ToolInput(tag="in_pi_shadow", input_type=Boolean(optional=True), prefix="-pishadow", doc=InputDocumentation(doc="[number]   - shadow length for shadow cases, default 15")), ToolInput(tag="in_pi_shadow_err", input_type=Boolean(optional=True), prefix="-pishadow_err", doc=InputDocumentation(doc="[number] - errors per 100 identities tolerated, 3")), ToolInput(tag="in_pi_seq_max", input_type=Boolean(optional=True), prefix="-piseqmax", doc=InputDocumentation(doc="- indexes can assumme maximum length of seq")), ToolInput(tag="in_pi_seq_max_len", input_type=Boolean(optional=True), prefix="-piseqmax_len", doc=InputDocumentation(doc="[number] - assummed max sequnce length, default 1000"))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Scanwise_V0_1_0().translate("wdl", allow_empty_container=True)

